==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAbstractTextDocumentLayout_shell.h <==
#ifndef QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H
#define QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


class QAbstractTextDocumentLayout_shell : public QAbstractTextDocumentLayout, public QtJambiShellInterface
{
public:
    QAbstractTextDocumentLayout_shell(QTextDocument* doc0);
    ~QAbstractTextDocumentLayout_shell() override;

    QRectF blockBoundingRect(const QTextBlock& block0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void documentChanged(int from0, int charsRemoved1, int charsAdded2) override;
    QSizeF documentSize() const override;
    void draw(QPainter* painter0, const QAbstractTextDocumentLayout::PaintContext& context1) override;
    void drawInlineObject(QPainter* painter0, const QRectF& rect1, QTextInlineObject object2, int posInDocument3, const QTextFormat& format4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QRectF frameBoundingRect(QTextFrame* frame0) const override;
    int hitTest(const QPointF& point0, Qt::HitTestAccuracy accuracy1) const override;
    int pageCount() const override;
    void positionInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void resizeInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTextDocumentLayout_access : public QAbstractTextDocumentLayout
{
    jobject __qt_format_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0);
    jint __qt_formatIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0);
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    void __qt_documentChanged_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint from0, jint charsRemoved1, jint charsAdded2);
    jobject __qt_documentSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_draw_QPainter_ptr_cref_QAbstractTextDocumentLayout_PaintContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID context1);
    void __qt_drawInlineObject_QPainter_ptr_cref_QRectF_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID object2, jint posInDocument3, QtJambiNativeID format4);
    jobject __qt_frameBoundingRect_QTextFrame_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frame0) const;
    jint __qt_hitTest_cref_QPointF_Qt_HitTestAccuracy_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0, jint accuracy1) const;
    jint __qt_pageCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_positionInlineObject_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint posInDocument1, QtJambiNativeID format2);
    void __qt_resizeInlineObject_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint posInDocument1, QtJambiNativeID format2);
};

#endif // QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QAbstractTextDocumentLayout_shell.h <==
#ifndef QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H
#define QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextlayout.h>
#include <QtGui/qtextobject.h>
#include <QtJambi/RegistryAPI>


class QAbstractTextDocumentLayout_shell : public QAbstractTextDocumentLayout, public QtJambiShellInterface
{
public:
    QAbstractTextDocumentLayout_shell(QTextDocument* doc0);
    ~QAbstractTextDocumentLayout_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QAbstractTextDocumentLayout_mshell;
    friend class QAbstractTextDocumentLayout_oshell;
};


class QAbstractTextDocumentLayout_mshell : public QAbstractTextDocumentLayout_shell
{
public:
    using QAbstractTextDocumentLayout_shell::QAbstractTextDocumentLayout_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAbstractTextDocumentLayout_oshell : public QAbstractTextDocumentLayout_mshell
{
public:
    using QAbstractTextDocumentLayout_mshell::QAbstractTextDocumentLayout_mshell;
    QRectF blockBoundingRect(const QTextBlock& block0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void documentChanged(int from0, int charsRemoved1, int charsAdded2) override;
    QSizeF documentSize() const override;
    void draw(QPainter* painter0, const QAbstractTextDocumentLayout::PaintContext& context1) override;
    void drawInlineObject(QPainter* painter0, const QRectF& rect1, QTextInlineObject object2, int posInDocument3, const QTextFormat& format4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QRectF frameBoundingRect(QTextFrame* frame0) const override;
    int hitTest(const QPointF& point0, Qt::HitTestAccuracy accuracy1) const override;
    int pageCount() const override;
    void positionInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void resizeInlineObject(QTextInlineObject item0, int posInDocument1, const QTextFormat& format2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTextDocumentLayout_access : public QAbstractTextDocumentLayout
{
    jobject __qt_format_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0);
    jint __qt_formatIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint pos0);
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    void __qt_documentChanged_int_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint from0, jint charsRemoved1, jint charsAdded2);
    jobject __qt_documentSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_draw_QPainter_ptr_cref_QAbstractTextDocumentLayout_PaintContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID context1);
    void __qt_drawInlineObject_QPainter_ptr_cref_QRectF_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID object2, jint posInDocument3, QtJambiNativeID format4);
    jobject __qt_frameBoundingRect_QTextFrame_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID frame0) const;
    jint __qt_hitTest_cref_QPointF_Qt_HitTestAccuracy_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID point0, jint accuracy1) const;
    jint __qt_pageCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_positionInlineObject_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint posInDocument1, QtJambiNativeID format2);
    void __qt_resizeInlineObject_QTextInlineObject_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0, jint posInDocument1, QtJambiNativeID format2);
};

#endif // QABSTRACTTEXTDOCUMENTLAYOUT_SHELL_H
